"use strict";

exports.__esModule = true;
exports["default"] = void 0;

var _default = function _default(field, fields) {
  return new Promise(function (resolve, reject) {
    var errors = {};

    var machineNames = _.map(fields, function (field, uuid) {
      if (uuid !== field.uuid) {
        return field.machineName;
      }
    });

    if (['text', 'select', 'checkbox', 'radio', 'date', 'file', 'survey', 'quiz', 'signature', 'list', 'section'].includes(field.type)) {
      if (!field.name || field.name === '') {
        errors.name = 'Name is required';
      }

      if (!field.machineName || field.machineName === '') {
        errors.machineName = 'Machine Name is required';
      } else if (machineNames.includes(field.machineName)) {
        errors.machineName = 'This Machine Name already exists';
      }

      if (field.config.isConditionalEnabled) {
        var conditionErrors = validateConditional(field.config.conditionalLogic.conditions);

        if (conditionErrors.length) {
          errors.conditionalLogic = conditionErrors;
        }
      }

      if (field.type === 'text' && field.config.regex && field.config.regex !== '') {
        try {
          new RegExp(field.config.regex);
        } catch (e) {
          errors.regex = 'Regex is not valid';
        }
      }
    }

    if (field.type === 'content') {
      if (!field.config.content || field.config.content === '') {
        errors.content = 'Content is required';
      }
    }

    if (field.type === 'select' || field.type === 'checkbox' || field.type === 'radio') {
      if (!field.config.optionReferenceId) {
        errors.options = 'Options are required';
      }
    }

    if (field.type === 'image' || field.type === 'video') {
      if (!field.config.url || field.config.url === '') {
        errors.upload = 'Url or file upload is required';
      } else if (!validURL(field.config.url)) {
        errors.url = 'Url is not valid';
      }
    }

    if (_.size(errors)) {
      reject(errors);
    } else {
      resolve({});
    }
  });
};

exports["default"] = _default;

var validateConditional = function validateConditional(conditions) {
  var errors = [];
  conditions.map(function (condition, index) {
    errors[index] = {};

    if (!condition.field) {
      errors[index].field = 'Field is required';
    }

    if (!condition.operator) {
      errors[index].operator = 'Operator is required';
    }

    if (!condition.value || condition.value === '') {
      errors[index].value = 'Value is required';
    }

    if (_.size(errors[index]) === 0) {
      delete errors[index];
    }
  });
  errors = errors.filter(function (el) {
    return el != null;
  });
  return errors;
};

var validURL = function validURL(str) {
  var pattern = new RegExp('^(https?:\\/\\/)?' + // protocol
  '((([a-z\\d]([a-z\\d-]*[a-z\\d])*)\\.)+[a-z]{2,}|' + // domain name
  '((\\d{1,3}\\.){3}\\d{1,3}))' + // OR ip (v4) address
  '(\\:\\d+)?(\\/[-a-z\\d%_.~+]*)*' + // port and path
  '(\\?[;&a-z\\d%_.~+=-]*)?' + // query string
  '(\\#[-a-z\\d_]*)?$', 'i'); // fragment locator

  return !!pattern.test(str);
};

module.exports = exports.default;